@@ -13,7 +13,9 @@ file in the current directory uranium was
 invoked in. this can be overridden by passing in a
 path to a <uranium_file>
 """
+from contextlib import contextmanager
 from docopt import docopt
+from virtualenv import make_environment_relocatable
 from .uranium import Uranium
 from .config import load_config_from_file
 import os
@@ -23,11 +25,14 @@ DEFAULT_URANIUM_FILE = "uranium.yaml"
 
 
 def main(argv=sys.argv[1:]):
-    _activate_virtualenv(os.curdir)
+
     options = docopt(__doc__,  argv=argv)
+    uranium_dir = os.path.abspath(os.curdir)
     uranium_file = options['<uranium_file>'] or DEFAULT_URANIUM_FILE
     uranium = _get_uranium(uranium_file)
-    uranium.run()
+
+    with in_virtualenv(uranium_dir):
+        uranium.run()
 
 
 def _get_uranium(uranium_file):
@@ -36,15 +41,23 @@ def _get_uranium(uranium_file):
     return Uranium(config, root)
 
 
+@contextmanager
+def in_virtualenv(path):
+    # we activate the virtualenv
+    _activate_virtualenv(path)
+
+    yield
+
+    # we end my making the virtualenv environment relocatable
+    make_environment_relocatable(path)
+
+
 def _activate_virtualenv(uranium_dir):
     """ this will activate a virtualenv in the case one exists """
+    uranium_dir = os.path.abspath(uranium_dir)
     activate_this_path = os.path.join(uranium_dir, 'bin', 'activate_this.py')
     with open(activate_this_path) as fh:
         exec(fh.read(), {'__file__': activate_this_path}, {})
 
-    # if the pyvenv launcher environment variable is set, it causes the install directory
-    # to be that directory.
-    # we want the virtualenv directory to be the one we just created, so we remove
-    # this variable
-    if '__PYVENV_LAUNCHER__' in os.environ:
-        del os.environ['__PYVENV_LAUNCHER__']
+    # we modify the executable directly, because pip invokes this to install packages.
+    sys.executable = os.path.join(uranium_dir, 'bin', 'python')
