@@ -28,14 +28,19 @@ class ClassLoader(object):
         <module>
         """
         egg_name = None
-        module = class_spec
+        module_path = class_spec
         if ':' in class_spec:
-            egg_name, module = class_spec.split(':')
+            egg_name, module_path = class_spec.split(':')
+
+        module = importlib.import_module(module_path)
+
+        if module:
+            return module
 
         if egg_name:
             self._install_egg(egg_name)
 
-        return self.get_class(module)
+        return self.get_module(module)
 
     def get_class(self, class_module_path):
         """
